# ontologia/codicem/hxl/standard/core

## HXLStandard
- https://hxlstandard.org/

### ontologia/codicem/hxl/standard/core/attribute.hxl.csv
- [standard/core/attribute.hxl.csv](standard/core/attribute.hxl.csv)
- `urn:data:xz:hxl:standard:core:attribute`
- https://data.humdata.org/dataset/hxl-core-schemas

### ontologia/codicem/hxl/standard/core/hashtag.hxl.csv
- [standard/core/hashtag.hxl.csv](standard/core/hashtag.hxl.csv)
- `urn:data:xz:hxl:standard:core:hashtag`
- https://data.humdata.org/dataset/hxl-core-schemas

### ontologia/codicem/hxl/standard/master-vocabulary.hxl.csv
- [standard/master-vocabulary.hxl.csv](standard/master-vocabulary.hxl.csv)
- `urn:data:xz:hxl:standard:master-vocabulary`
- https://data.humdata.org/dataset/hxl-master-vocabulary-list

## HXL-CPLP

### ontologia/codicem/hxl/cplp/hxl2tab.hxl.csv
- [cplp/hxl2tab.hxl.csv](cplp/hxl2tab.hxl.csv)
- `urn:data:xz:hxlcplp:hxl2tab`
- https://github.com/EticaAI/HXL-Data-Science-file-formats/issues/2
- https://docs.google.com/spreadsheets/d/1vFkBSharAEg5g5K2u_iDLCBvpWWPqpzC1hcL6QpFNZY/edit#gid=245471857

<!--
## binarium.hxl.csv
- [binarium.hxl.csv](binarium.hxl.csv)
- `urn:data:xz:eticaai:ontologia:codicem:sexum:binarium`
- https://github.com/HXL-CPLP/forum/issues/50
- https://en.wikipedia.org/wiki/ISO/IEC_5218

## non-binarium.hxl.csv
- [non-binarium.hxl.csv](non-binarium.hxl.csv)
- `urn:data:xz:eticaai:ontologia:codicem:sexum:non-binarium`
- https://github.com/HXL-CPLP/forum/issues/50
- https://en.wikipedia.org/wiki/ISO/IEC_5218
- https://confluence.hl7.org/display/VOC/Gender+Coding+with+International+Data+Exchange+Standards

## hl7.hxl.csv
- [hl7.hxl.csv](hl7.hxl.csv)
- `urn:data:xz:eticaai:ontologia:codicem:sexum:hl7`
- https://github.com/HXL-CPLP/forum/issues/50
- https://en.wikipedia.org/wiki/ISO/IEC_5218
- https://confluence.hl7.org/display/VOC/Gender+Coding+with+International+Data+Exchange+Standards
-->